summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h')
-rw-r--r--chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h b/chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h
index 10d4f23588a..fcfbeb7f234 100644
--- a/chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h
+++ b/chromium/third_party/blink/renderer/platform/fonts/shaping/glyph_bounds_accumulator.h
@@ -86,12 +86,12 @@ struct GlyphBoundsAccumulator {
// Convert physical glyph_bounding_box to logical.
bounds = bounds.TransposedRect();
// The glyph bounding box of a vertical run uses ideographic baseline.
// Adjust the box Y position because the bounding box of a ShapeResult uses
// alphabetic baseline.
// See diagrams of base lines at
// https://drafts.csswg.org/css-writing-modes-3/#intro-baselines
- int baseline_adjust = font_metrics.Ascent(kIdeographicBaseline) -
+ int baseline_adjust = font_metrics.Ascent(kCentralBaseline) -
font_metrics.Ascent(kAlphabeticBaseline);
bounds.SetY(bounds.Y() + baseline_adjust);
}
@@ -86,12 +86,12 @@ struct GlyphBoundsAccumulator {
// Convert physical glyph_bounding_box to logical.
bounds = bounds.TransposedRect();
- // The glyph bounding box of a vertical run uses ideographic baseline.
- // Adjust the box Y position because the bounding box of a ShapeResult uses
- // alphabetic baseline.
+ // The glyph bounding box of a vertical run uses ideographic central
+ // baseline. Adjust the box Y position because the bounding box of a
+ // ShapeResult uses alphabetic baseline.
// See diagrams of base lines at
// https://drafts.csswg.org/css-writing-modes-3/#intro-baselines